Method: Unityapi::UnityClient#get_vitals
- Defined in:
- lib/unityapi/unity_client.rb
#get_vitals ⇒ Object
returns xml description of all vitals forms used in EHR
340 341 342 343 |
# File 'lib/unityapi/unity_client.rb', line 340 def get_vitals #returns xml description of all vitals forms used in EHR response = magic_action("GetVitals") return response.body[:magic_response][:magic_result][:diffgram][:getvitalsresponse][:getvitalsinfo] end |